diff --git a/doc/salome/gui/GEOM/input/creating_3dsketcher.doc b/doc/salome/gui/GEOM/input/creating_3dsketcher.doc
index 31b410749..fcc0ba56d 100755
--- a/doc/salome/gui/GEOM/input/creating_3dsketcher.doc
+++ b/doc/salome/gui/GEOM/input/creating_3dsketcher.doc
@@ -4,7 +4,7 @@
3D Sketcher allows creating a closed or unclosed 3D wire from a list of points.
-To create a 3D Sketch, select in the main menu New Entity -> 3D Sketch.
+To create a 3D Sketch, select in the main menu New Entity -> Basic -> 3D Sketch.
\image html 3dsketch2.png
diff --git a/doc/salome/gui/GEOM/input/creating_adv_obj.doc b/doc/salome/gui/GEOM/input/creating_adv_obj.doc
index 030b88666..eb11522cf 100644
--- a/doc/salome/gui/GEOM/input/creating_adv_obj.doc
+++ b/doc/salome/gui/GEOM/input/creating_adv_obj.doc
@@ -2,18 +2,6 @@
\page create_adv_obj_page Creating Advanced Geometrical Objects
-New Entity -> Build submenu allows to create topological
-entities:
-
-
-
\subpage create_edge_page
-
\subpage create_wire_page
-
\subpage create_face_page
-
\subpage create_shell_page
-
\subpage create_solid_page
-
\subpage create_compound_page
-
-
New Entity -> Advanced submenu allows to create additional complex topological objects.
-*/
\ No newline at end of file
+*/
diff --git a/doc/salome/gui/GEOM/input/creating_geom_objects.doc b/doc/salome/gui/GEOM/input/creating_geom_objects.doc
index 8074dc657..2db4f00dc 100644
--- a/doc/salome/gui/GEOM/input/creating_geom_objects.doc
+++ b/doc/salome/gui/GEOM/input/creating_geom_objects.doc
@@ -9,19 +9,16 @@ range of geometrical objects, from points to complex extrusions:
\note It is possible to use the variables defined in the SALOME \b NoteBook
diff --git a/doc/salome/gui/GEOM/input/creating_pipetshape.doc b/doc/salome/gui/GEOM/input/creating_pipetshape.doc
index 21ba76bf1..b7f448ed9 100644
--- a/doc/salome/gui/GEOM/input/creating_pipetshape.doc
+++ b/doc/salome/gui/GEOM/input/creating_pipetshape.doc
@@ -2,8 +2,7 @@
\page create_pipetshape_page PipeTShape
-To create a \b PipeTShape in the Main Menu select New Entity - >
-Advanced - > PipeTShape
+To create a \b PipeTShape in the Main Menu select New Entity -> Primitives -> PipeTShape
Specify the parameters of the PipeTShape object in the opened dialog
box and press "Apply" or "Apply & Close" button.
diff --git a/doc/salome/gui/GEOM/input/creating_primitives.doc b/doc/salome/gui/GEOM/input/creating_primitives.doc
index 9a1ab84b1..467fe3ac5 100644
--- a/doc/salome/gui/GEOM/input/creating_primitives.doc
+++ b/doc/salome/gui/GEOM/input/creating_primitives.doc
@@ -2,7 +2,7 @@
\page create_primitives_page Creating Primitives
-New Entity -> Primitives submenu allows to create voluminal
+New Entity -> Primitives submenu allows to create volumical
geometrical objects, such as:
diff --git a/doc/salome/gui/GEOM/input/creating_sketcher.doc b/doc/salome/gui/GEOM/input/creating_sketcher.doc
index fd7553df2..85ce73f4d 100644
--- a/doc/salome/gui/GEOM/input/creating_sketcher.doc
+++ b/doc/salome/gui/GEOM/input/creating_sketcher.doc
@@ -1,17 +1,17 @@
/*!
-\page create_sketcher_page Sketcher
+\page create_sketcher_page 2D Sketcher
-The sketcher allows you to create a profile made of curves of 2 types: line segments and arcs.
+The 2D Sketcher allows you to create a profile made of curves of 2 types: line segments and arcs.
Example:
\image html sketch_example.png
-To create a \b Sketch:
+To create a \b 2D Sketch:
-
In the main menu select New Entity / Sketch or click on \image html sketch.png
+
In the main menu select New Entity -> Basic -> 2D Sketch or click on \image html sketch.png
Select the plane or the planar face on which to create the sketch. By default the sketch is created on the XOY plane of the global coordinate system.
If Local Coordinate systems have been created in the study they appear in the combobox and can be selected as reference coordinate system.
*/
\ No newline at end of file
diff --git a/doc/salome/gui/GEOM/input/tui_sketcher.doc b/doc/salome/gui/GEOM/input/tui_sketcher.doc
index 31c576f23..e344eae27 100644
--- a/doc/salome/gui/GEOM/input/tui_sketcher.doc
+++ b/doc/salome/gui/GEOM/input/tui_sketcher.doc
@@ -1,6 +1,6 @@
/*!
-\page tui_sketcher_page Sketcher
+\page tui_sketcher_page 2D Sketcher
\code
import geompy
@@ -45,4 +45,4 @@ gg.createAndDisplayGO(id_sketcher1)
gg.createAndDisplayGO(id_sketcher2)
\endcode
-*/
\ No newline at end of file
+*/
diff --git a/doc/salome/gui/GEOM/input/tui_test_all.doc b/doc/salome/gui/GEOM/input/tui_test_all.doc
index de0b46250..2fe8d7623 100644
--- a/doc/salome/gui/GEOM/input/tui_test_all.doc
+++ b/doc/salome/gui/GEOM/input/tui_test_all.doc
@@ -37,6 +37,9 @@
\anchor swig_MakeVertexOnSurface
\until p_on_face
+\anchor swig_MakeVertexOnSurfaceByCoord
+\until p_on_face2
+
\until S = geompy.MakeRotation
\anchor swig_MakeLineTwoFaces
@@ -45,6 +48,9 @@
\anchor swig_all_advanced
\until MakeSewing
+\anchor swig_MakeCopy
+\until MakeCopy
+
\anchor swig_all_trsf
\until RotatPnt
@@ -57,6 +63,9 @@
\anchor swig_ChangeOrientation
\until ChangeOrientation
+\anchor swig_ExtractShapes
+\until prism_edges
+
\anchor swig_FilletChamfer
\until End of Local operations
@@ -72,6 +81,12 @@
\anchor swig_all_addtostudy
\until id_Partition1
+\anchor swig_all_addtostudyInFather
+\until id_SubFace
+
+\anchor swig_SubShapeName
+\until nameS
+
\anchor swig_all_decompose
\until print "DONE"
diff --git a/doc/salome/tui/Makefile.am b/doc/salome/tui/Makefile.am
index d14ad47ae..a2b5e1a66 100644
--- a/doc/salome/tui/Makefile.am
+++ b/doc/salome/tui/Makefile.am
@@ -32,9 +32,7 @@ dev_docs: doxyfile
echo "===========================================" ; \
echo "Replacing geompyDC by geompy" ; \
echo "===========================================" ; \
- sed -e "/class geompyDC/d" -e "s/^ *#/#/g" -e "s/^ *def /def /g" \
- -e "s/geompyDC/geompy/g" $(top_srcdir)/src/GEOM_SWIG/geompyDC.py > \
- ./geompy.py ; \
+ $(KERNEL_ROOT_DIR)/bin/salome/prepare_generating_doc.py geompy.py $(top_srcdir)/src/GEOM_SWIG/geompyDC.py geompy ; \
echo "===========================================" ; \
echo "Generating TUI documentation" ; \
echo "===========================================" ; \
diff --git a/idl/GEOM_Gen.idl b/idl/GEOM_Gen.idl
index 1792e88e2..9fd614d99 100644
--- a/idl/GEOM_Gen.idl
+++ b/idl/GEOM_Gen.idl
@@ -273,7 +273,7 @@ module GEOM
/*!
* Toggle auto color mode on the object.
- * \param theAtoColor is a flag which toggles auto color mode.
+ * \param theAutoColor is a flag which toggles auto color mode.
*/
void SetAutoColor(in boolean theAutoColor);
@@ -499,8 +499,8 @@ module GEOM
*/
GEOM_Object MakePointOnCurveByCoord (in GEOM_Object theRefCurve,
in double theXParameter,
- in double theYarameter,
- in double theZPameter);
+ in double theYParameter,
+ in double theZParameter);
/*!
* \brief Create a point, corresponding to the given parameters on the
@@ -524,8 +524,8 @@ module GEOM
*/
GEOM_Object MakePointOnSurfaceByCoord (in GEOM_Object theRefSurf,
in double theXParameter,
- in double theYarameter,
- in double theZPameter);
+ in double theYParameter,
+ in double theZParameter);
/*!
@@ -540,8 +540,8 @@ module GEOM
* \brief Create a vector, corresponding to tangent to the given parameter on the given curve.
* \param theRefCurve The referenced curve.
* \param theParameter Value of parameter on the referenced curve.This value should be have value
- * \between 0. and 1.. Value of 0. corresponds first parameter of curve value 1. corresponds
- * \last parameter of curve.
+ * between 0. and 1.. Value of 0. corresponds first parameter of curve; value
+ * 1. corresponds last parameter of curve.
* \return New GEOM_Object, containing the created point.
*/
GEOM_Object MakeTangentOnCurve (in GEOM_Object theRefCurve,
@@ -628,7 +628,7 @@ module GEOM
/*!
* \brief Create a plane, by two vectors.
* \param theVec1 Vector1, the plane has to pass through first point of this vector.
- * \param theVec Vector2, defining the plane normal direction.
+ * \param theVec2 Vector2, defining the plane normal direction.
* \param theTrimSize Half size of a side of quadrangle face, representing the plane.
* \return New GEOM_Object, containing the created plane.
*/
@@ -761,7 +761,7 @@ module GEOM
* \param theObject The object to be translated.
* \param theVector Translation vector, giving a direction.
* \param theDistance Translation distance, giving a distance.
- * \param theCope Translation copy, creating its copy if true.
+ * \param theCopy Translation copy, creating its copy if true.
* \return New GEOM_Object, containing the translated object.
*/
GEOM_Object TranslateVectorDistance (in GEOM_Object theObject,
@@ -807,8 +807,8 @@ module GEOM
* \brief Rotate given object around vector perpendicular to plane containing three points.
* \param theObject The object to be rotated.
* \param theCentPoint central point - the axis is the vector perpendicular to the plane
- * containing the three points.
- * \param thePoint1 and thePoint2 - in a perpendicular plan of the axis.
+ * containing the three points.
+ * \param thePoint1,thePoint2 - in a perpendicular plan of the axis.
* \return theObject.
*/
GEOM_Object RotateThreePoints (in GEOM_Object theObject,
@@ -824,7 +824,7 @@ module GEOM
* \param theObject The object to be rotated.
* \param theCentPoint central point - the axis is the vector perpendicular to the plane
* containing the three points.
- * \param thePoint1 and thePoint2 - in a perpendicular plan of the axis.
+ * \param thePoint1,thePoint2 - in a perpendicular plan of the axis.
* \return New GEOM_Object, containing the rotated object.
*/
GEOM_Object RotateThreePointsCopy (in GEOM_Object theObject,
@@ -1053,7 +1053,7 @@ module GEOM
* \param thePath Wire or Edge along that the object will be translated.
* \param theDistance progress of Path (0 = actual location, 1 = end of path location).
* \param theCopy is a true or false parameter. true is to create a copy, false to move the object.
- * \param theCopy is a true or false parameter. true is to reverse direction, false is to move normal direction.
+ * \param theReverse is a true or false parameter. true is to reverse direction, false is to move normal direction.
* \return New GEOM_Object, containing the displaced shape.
*/
GEOM_Object PositionAlongPath (in GEOM_Object theObject,
@@ -1125,7 +1125,7 @@ module GEOM
/*!
* \brief Create a face by normale vector or edge and two specified sizes,
* vertical (H) and horisontal (W).
- * \param theVec defines plane.
+ * \param theObj defines plane.
* \param theH vertical size (height).
* \param theW horisontal size (width).
* \return New GEOM_Object, containing the created face.
@@ -1298,7 +1298,7 @@ module GEOM
/*!
* \brief Create a shape by extrusion of the base shape along a vector, defined by DX DY DZ.
* \param theBase Base shape to be extruded.
- * \param DX, DY, DZ end of extrusion vector.
+ * \param theDX, theDY, theDZ end of extrusion vector.
* \return New GEOM_Object, containing the created prism.
*/
GEOM_Object MakePrismDXDYDZ (in GEOM_Object theBase,
@@ -1358,12 +1358,14 @@ module GEOM
/*!
* \brief Create a filling from the given compound of contours.
+ * \param theShape Initial shape on which to perform the feature.
* \param theMinDeg a minimal degree of BSpline surface to create
* \param theMaxDeg a maximal degree of BSpline surface to create
* \param theTol2D a 2d tolerance to be reached
* \param theTol3D a 3d tolerance to be reached
* \param theNbIter a number of iteration of approximation algorithm
* \param theMethod Kind of method to perform filling operation.
+ * \param theApprox Boolean indicating if result should be approximated
* \return New GEOM_Object, containing the created filling surface.
*/
GEOM_Object MakeFilling (in GEOM_Object theShape,
@@ -1399,7 +1401,7 @@ module GEOM
* \param thePath - Path shape to extrude the base shape along it.
* \param theWithContact - the mode defining that the section is translated to be in
* contact with the spine.
- * \param - WithCorrection - defining that the section is rotated to be
+ * \param theWithCorrection - defining that the section is rotated to be
* orthogonal to the spine tangent in the correspondent point
* \return New GEOM_Object, containing the created pipe.
*/
@@ -1423,7 +1425,7 @@ module GEOM
* \param thePath - Path shape to extrude the base shape along it.
* \param theWithContact - the mode defining that the section is translated to be in
* contact with the spine.
- * \param - WithCorrection - defining that the section is rotated to be
+ * \param theWithCorrection - defining that the section is rotated to be
* orthogonal to the spine tangent in the correspondent point
* \return New GEOM_Object, containing the created pipe.
*/
@@ -1613,7 +1615,7 @@ module GEOM
* in compliance with given list of edges
* \param theShape Initial shape.
* \param theTolerance Maximum distance between edges, which can be considered as coincident.
- * \param theFaces List of edges for gluing.
+ * \param theEdges List of edges for gluing.
* \return New GEOM_Object, containing a copy of theShape without some edges.
*/
GEOM_Object MakeGlueEdgesByList (in GEOM_Object theShape,
@@ -1815,7 +1817,7 @@ module GEOM
in GEOM_Object theAx1,
in shape_state theState);
/*!
- * \briefFind in \a theShape all sub-shapes of type \a theShapeType, situated relatively
+ * \brief Find in \a theShape all sub-shapes of type \a theShapeType, situated relatively
* the specified plane by the certain way, defined through \a theState parameter.
* \param theShape Shape to find sub-shapes of.
* \param theShapeType Type of sub-shapes to be retrieved.
@@ -2167,7 +2169,7 @@ module GEOM
* faces is not important.
*
* It is not necessary that Faces share the same edge.
- * \param theFace1-theFace6 Faces for the hexahedral solid.
+ * \param theFace1,theFace2,theFace3,theFace4,theFace5,theFace6 Faces for the hexahedral solid.
* \return New GEOM_Object, containing the created solid.
*/
GEOM_Object MakeHexa (in GEOM_Object theFace1,
@@ -2236,7 +2238,7 @@ module GEOM
/*!
* \brief Returns a face, found in the given shape by four given corner vertices.
* \param theShape Block or a compound of blocks.
- * \param thePoint1-thePoint4 Points, close to the corners of the desired face.
+ * \param thePoint1,thePoint2,thePoint3,thePoint4 Points, close to the corners of the desired face.
* \return New GEOM_Object, containing the found face.
*/
GEOM_Object GetFaceByPoints (in GEOM_Object theShape,
@@ -2275,7 +2277,7 @@ module GEOM
/*!
* \brief Find a face of block, whose outside normale has minimal angle with the given vector.
- * \param theShape Block or a compound of blocks.
+ * \param theBlock Block or a compound of blocks.
* \param theVector Vector, close to the normale of the desired face.
* \return New GEOM_Object, containing the found face.
*/
@@ -2307,8 +2309,8 @@ module GEOM
* \param theMinNbFaces If solid has lower number of faces, it is not a block.
* \param theMaxNbFaces If solid has higher number of faces, it is not a block.
* \note If theMaxNbFaces = 0, the maximum number of faces is not restricted.
+ * \param theNbBlocks Number of specified blocks in theCompound.
* \return TRUE, if the given compound contains only blocks.
- * \return theNbBlocks Number of specified blocks in theCompound.
*/
boolean IsCompoundOfBlocks (in GEOM_Object theCompound,
in long theMinNbFaces,
@@ -2361,8 +2363,8 @@ module GEOM
* - The glue between two quadrangle faces should be applied.
* \note Single block is also accepted as a valid compound of blocks.
* \param theCompound The compound to check.
+ * \param theErrors Structure, containing discovered errors and incriminated sub-shapes.
* \return TRUE, if the given shape is a compound of blocks.
- * \return theErrors Structure, containing discovered errors and incriminated sub-shapes.
*/
boolean CheckCompoundOfBlocks (in GEOM_Object theCompound,
out BCErrors theErrors);
@@ -2518,7 +2520,7 @@ module GEOM
* \note Each compound from ListShapes and ListTools will be exploded in order
* to avoid possible intersection between shapes from this compound.
* \param theLimit Type of resulting shapes (corresponding to TopAbs_ShapeEnum).
- * \param KeepNonlimitShapes: if this parameter == 0, then only shapes of
+ * \param theKeepNonlimitShapes: if this parameter == 0, then only shapes of
* target type (equal to Limit) are kept in the result,
* else standalone shapes of lower dimension
* are kept also (if they exist).
@@ -2734,7 +2736,7 @@ module GEOM
* \param thezExpr parametric equation of the coordinates Z.
* \param theParamMin the minimal value of the parameter.
* \param theParamMax the maximum value of the parameter.
- * \param theParamStep the number of steps of the parameter discretization.
+ * \param theParamNbStep the number of steps of the parameter discretization.
* \param theCurveType the type of the curve.
* \return New GEOM_Object, containing the created curve.
*/
@@ -2944,7 +2946,7 @@ module GEOM
* \brief Perform a chamfer on edges,
* with distance D1 on the first specified face (if several for one edge)
* \param theShape Shape, to perform chamfer on.
- * \param theD1 theD2 Chamfer size
+ * \param theD1,theD2 Chamfer size
* \param theEdges Sequence of edges of \a theShape.
* \return New GEOM_Object, containing the result shape.
*/
@@ -3363,7 +3365,7 @@ module GEOM
/*!
* \brief Get inertia matrix and moments of inertia of theShape.
* \param theShape Shape to calculate inertia of.
- * \param I(1-3)(1-3) Output. Components of the inertia matrix of the given shape.
+ * \param I11,I12,I13,I21,I22,I23,I31,I32,I33 Output. Components of the inertia matrix of the given shape.
* \param Ix,Iy,Iz Output. Moments of inertia of the given shape.
* \return Returns inertia through the last twelve arguments.
*/
@@ -3843,7 +3845,24 @@ module GEOM
*
* To be used from GUI and from geompy.addToStudy.
* Work like the above method, but accepts study object theSObject instead of GEOM_Object.
+ * \param theStudy the study, in which theObject is published already,
+ * and in which the arguments will be published
* \param theSObject study object, referencing GEOM_Object, arguments of which will be published
+ * \param theArgs list of GEOM_Object, operation arguments to be published.
+ * If this list is empty, all operation arguments will be published
+ * \param theFindMethod method to search sub-shapes, corresponding to arguments and
+ * their sub-shapes. Value from enumeration GEOM::find_shape_method.
+ * \param theInheritFirstArg set properties of the first argument for \a theObject.
+ * Do not publish sub-shapes in place of arguments, but only
+ * in place of sub-shapes of the first argument,
+ * because the whole shape corresponds to the first argument.
+ * Mainly to be used after transformations, but it also can be
+ * usefull after partition with one object shape, and some other
+ * operations, where only the first argument has to be considered.
+ * If theObject has only one argument shape, this flag is automatically
+ * considered as True, not regarding really passed value.
+ * \param theAddPrefix add prefix "from_" to names of restored sub-shapes,
+ * and prefix "from_subshapes_of_" to names of partially restored sub-shapes.
*/
ListOfGO RestoreSubShapesSO (in SALOMEDS::Study theStudy,
in SALOMEDS::SObject theSObject,
diff --git a/src/GEOMGUI/GEOM_msg_en.ts b/src/GEOMGUI/GEOM_msg_en.ts
index 955f04638..8507309a9 100644
--- a/src/GEOMGUI/GEOM_msg_en.ts
+++ b/src/GEOMGUI/GEOM_msg_en.ts
@@ -3074,6 +3074,14 @@ Please, select face, shell or solid and try again
Create a box
+
+
+ Shape recognition
+
+
+
+ Import picture in viewer
+ Create a chamfer
@@ -3206,6 +3214,14 @@ Please, select face, shell or solid and try again
Create an extrusion
+
+
+ Extruded cut
+
+
+
+ Extruded boss
+ Build a face
diff --git a/src/GEOMGUI/GEOM_msg_fr.ts b/src/GEOMGUI/GEOM_msg_fr.ts
index ae363d04c..74a7da647 100644
--- a/src/GEOMGUI/GEOM_msg_fr.ts
+++ b/src/GEOMGUI/GEOM_msg_fr.ts
@@ -2993,6 +2993,14 @@ Choisissez une face, une coque ou un solide et essayez de nouveau
Créer une boîte
+
+
+ Reconnaisance de formes
+
+
+
+ Importer une image dans la vue
+ Créer un chanfrein
@@ -3125,6 +3133,14 @@ Choisissez une face, une coque ou un solide et essayez de nouveau
Créer une extrusion
+
+
+ Enlèvement de matière extrudé
+
+
+
+ Bossage extrudé
+ Construire une face
diff --git a/src/GEOMGUI/GeometryGUI.cxx b/src/GEOMGUI/GeometryGUI.cxx
index 4eebd7280..b9fa45797 100644
--- a/src/GEOMGUI/GeometryGUI.cxx
+++ b/src/GEOMGUI/GeometryGUI.cxx
@@ -2224,7 +2224,7 @@ QAction* GeometryGUI::getAction(const int id) {
This method can be re-implemented in the subclasses.
Return true in case if object isn't reference or component (module root).
- \param id column id
+ \param entry column id
\return \c true if the item can be renamed by the user in place (e.g. in the Object browser)
*/
bool GeometryGUI::renameAllowed( const QString& entry) const {
diff --git a/src/GEOMImpl/BRepTools_Modifier_21423.hxx b/src/GEOMImpl/BRepTools_Modifier_21423.hxx
index b0c81cea1..94da1fc42 100644
--- a/src/GEOMImpl/BRepTools_Modifier_21423.hxx
+++ b/src/GEOMImpl/BRepTools_Modifier_21423.hxx
@@ -52,7 +52,7 @@ public:
Standard_EXPORT BRepTools_Modifier_21423();
//! Creates a modifier on the shape .
Standard_EXPORT BRepTools_Modifier_21423(const TopoDS_Shape& S);
- //! Creates a modifier on the shape , and performs
+ //! Creates a modifier on the shape , and performs
//! the modifications described by .
Standard_EXPORT BRepTools_Modifier_21423(const TopoDS_Shape& S,const Handle(BRepTools_Modification)& M);
//! Initializes the modifier with the shape .
diff --git a/src/GEOMImpl/GEOMImpl_Block6Explorer.hxx b/src/GEOMImpl/GEOMImpl_Block6Explorer.hxx
index 4e1395a70..5f559a507 100644
--- a/src/GEOMImpl/GEOMImpl_Block6Explorer.hxx
+++ b/src/GEOMImpl/GEOMImpl_Block6Explorer.hxx
@@ -217,9 +217,10 @@ class GEOMImpl_Block6Explorer
/*!
* Build a face, bound by the given wire.
* \param theWire The initial wire to build the face on.
- * \param isPlanarWanted. If true, try to build a planar face.
+ * \param isPlanarWanted If true, try to build a planar face.
* \note If isPlanarWanted is true, but planar face cannot be built
* with acceptable tolerance, any face will be built.
+ * \param theResult The resulting shape.
* \return Error or warning description. Empty string in case of success.
*/
static TCollection_AsciiString MakeFace (const TopoDS_Wire& theWire,
@@ -229,6 +230,7 @@ class GEOMImpl_Block6Explorer
/*!
* Build a face, bound by the given wire.
* \param theWire The initial wire to build the face on.
+ * \param theResult The resulting shape.
* \return Error or warning description. Empty string in case of success.
*/
static TCollection_AsciiString MakeAnyFace (const TopoDS_Wire& theWire,
diff --git a/src/GEOMImpl/GEOMImpl_IAdvancedOperations.cxx b/src/GEOMImpl/GEOMImpl_IAdvancedOperations.cxx
index 4cbd6611f..15a0b8a53 100644
--- a/src/GEOMImpl/GEOMImpl_IAdvancedOperations.cxx
+++ b/src/GEOMImpl/GEOMImpl_IAdvancedOperations.cxx
@@ -1120,9 +1120,9 @@ bool GEOMImpl_IAdvancedOperations::MakePipeTShapeMirrorAndGlue(Handle(GEOM_Objec
//=============================================================================
/*!
* MakePipeTShape
- * Create a T-shape object with specified caracteristics for the main and
- * the incident pipes (radius, width, half-length).
- * Center of the shape is (0,0,0). The main plane of the T-shape is XOY.
+ * \brief Create a T-shape object with specified caracteristics for the main and
+ * the incident pipes (radius, width, half-length).
+ * Center of the shape is (0,0,0). The main plane of the T-shape is XOY.
* \param theR1 Internal radius of main pipe
* \param theW1 Width of main pipe
* \param theL1 Half-length of main pipe
@@ -1134,9 +1134,9 @@ bool GEOMImpl_IAdvancedOperations::MakePipeTShapeMirrorAndGlue(Handle(GEOM_Objec
*/
//=============================================================================
Handle(TColStd_HSequenceOfTransient)
-GEOMImpl_IAdvancedOperations::MakePipeTShape(double theR1, double theW1, double theL1,
- double theR2, double theW2, double theL2,
- bool theHexMesh)
+ GEOMImpl_IAdvancedOperations::MakePipeTShape(double theR1, double theW1, double theL1,
+ double theR2, double theW2, double theL2,
+ bool theHexMesh)
{
MESSAGE("GEOMImpl_IAdvancedOperations::MakePipeTShape");
SetErrorCode(KO);
@@ -1977,7 +1977,7 @@ GEOMImpl_IAdvancedOperations::MakePipeTShapeFillet(double theR1, double theW1, d
//=============================================================================
/*!
* MakePipeTShapeFilletWithPosition
- * Create a T-shape object with specified caracteristics for the main and
+ * \brief Create a T-shape object with specified caracteristics for the main and
* the incident pipes (radius, width, half-length). A fillet is created
* on the junction of the pipes.
* The extremities of the main pipe are located on junctions points P1 and P2.
diff --git a/src/GEOMToolsGUI/GEOMToolsGUI_DeleteDlg.cxx b/src/GEOMToolsGUI/GEOMToolsGUI_DeleteDlg.cxx
index 9b517f324..e88652ea8 100644
--- a/src/GEOMToolsGUI/GEOMToolsGUI_DeleteDlg.cxx
+++ b/src/GEOMToolsGUI/GEOMToolsGUI_DeleteDlg.cxx
@@ -71,6 +71,8 @@ static QStringList objectsToNames( const QMap& objects )
/*!
\brief Constructor.
\param parent parent widget
+ \param objects map of objects names/objects
+ \param deleteAll if True, delete all objects
*/
GEOMToolsGUI_DeleteDlg::GEOMToolsGUI_DeleteDlg( QWidget* parent,
const QMap& objects,
diff --git a/src/GEOMToolsGUI/GEOMToolsGUI_MaterialPropertiesDlg.cxx b/src/GEOMToolsGUI/GEOMToolsGUI_MaterialPropertiesDlg.cxx
index 77803fe92..3622c8a5c 100644
--- a/src/GEOMToolsGUI/GEOMToolsGUI_MaterialPropertiesDlg.cxx
+++ b/src/GEOMToolsGUI/GEOMToolsGUI_MaterialPropertiesDlg.cxx
@@ -573,6 +573,7 @@ void GEOMToolsGUI_MaterialPropertiesDlg::accept()
/*!
\brief Process key press event
+ \param o sender
\param e key event
*/
bool GEOMToolsGUI_MaterialPropertiesDlg::eventFilter( QObject* o, QEvent* e )
diff --git a/src/Material/Material_Model.cxx b/src/Material/Material_Model.cxx
index e41c1df68..a3fe7c876 100644
--- a/src/Material/Material_Model.cxx
+++ b/src/Material/Material_Model.cxx
@@ -319,6 +319,7 @@ void Material_Model::clearModel()
\param theResMgr resources manager
\param theResSection resources section name
+ \param theIsFront if True, it is front material, else it is back material
\sa save()
*/
void Material_Model::fromResources( QtxResourceMgr* theResMgr,
@@ -408,6 +409,7 @@ void Material_Model::fromResources( QtxResourceMgr* theResMgr,
\param theResMgr resources manager
\param theResSection resources section name
+ \param theIsFront if True, it is front material, else it is back material
\sa fromResources()
*/
void Material_Model::save( QtxResourceMgr* theResMgr,
diff --git a/src/ShapeRecognition/ShapeRec_FeatureDetector.cxx b/src/ShapeRecognition/ShapeRec_FeatureDetector.cxx
index b9a341e60..11cd47a0d 100644
--- a/src/ShapeRecognition/ShapeRec_FeatureDetector.cxx
+++ b/src/ShapeRecognition/ShapeRec_FeatureDetector.cxx
@@ -205,13 +205,13 @@ std::string ShapeRec_FeatureDetector::CroppImage()
/*!
Performs contours detection and store them in contours
- \param src - src image to find contours of
+ \param binaryImg - src image to find contours of
*/
-void ShapeRec_FeatureDetector::_detectAndRetrieveContours( Mat src )
+void ShapeRec_FeatureDetector::_detectAndRetrieveContours( Mat binaryImg )
{
- src = src > 1;
+ binaryImg = binaryImg > 1;
int method = CV_CHAIN_APPROX_NONE;
- findContours( src, contours, hierarchy,CV_RETR_CCOMP, method);
+ findContours( binaryImg, contours, hierarchy,CV_RETR_CCOMP, method);
// Other possible approximations CV_CHAIN_APPROX_TC89_KCOS, CV_CHAIN_APPROX_TC89_L1, CV_CHAIN_APPROX_SIMPLE cf. OpenCV documentation
// for precise information
}
diff --git a/src/GEOM_SWIG/geompyDC.py b/src/GEOM_SWIG/geompyDC.py
index dbf18eb98..0c717ce4f 100644
--- a/src/GEOM_SWIG/geompyDC.py
+++ b/src/GEOM_SWIG/geompyDC.py
@@ -430,7 +430,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
## Get name for sub-shape aSubObj of shape aMainObj
#
- # @ref swig_SubShapeAllSorted "Example"
+ # @ref swig_SubShapeName "Example"
def SubShapeName(self,aSubObj, aMainObj):
"""
Get name for sub-shape aSubObj of shape aMainObj
@@ -456,7 +456,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
# these arguments description
# \return study entry of the published shape in form of string
#
- # @ref swig_MakeQuad4Vertices "Example"
+ # @ref swig_all_addtostudy "Example"
def addToStudy(self, aShape, aName, doRestoreSubShapes=False,
theArgs=[], theFindMethod=GEOM.FSM_GetInPlace, theInheritFirstArg=False):
"""
@@ -494,7 +494,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
# \param aName the name for the shape
#
# \return study entry of the published shape in form of string
- # @ref swig_SubShapeAllSorted "Example"
+ # @ref swig_all_addtostudyInFather "Example"
def addToStudyInFather(self, aFather, aShape, aName):
"""
Publish in study aShape with name aName as sub-object of previously published aFather
@@ -517,22 +517,22 @@ class geompyDC(GEOM._objref_GEOM_Gen):
## Unpublish object in study
#
- # \param aobj the object to be unpublished
- def hideInStudy(self, obj):
+ # \param obj the object to be unpublished
+ def hideInStudy(self, obj):
"""
Unpublish object in study
Parameters:
obj the object to be unpublished
"""
- ior = salome.orb.object_to_string(obj)
- aSObject = self.myStudy.FindObjectIOR(ior)
- if aSObject is not None:
- genericAttribute = self.myBuilder.FindOrCreateAttribute(aSObject, "AttributeDrawable")
+ ior = salome.orb.object_to_string(obj)
+ aSObject = self.myStudy.FindObjectIOR(ior)
+ if aSObject is not None:
+ genericAttribute = self.myBuilder.FindOrCreateAttribute(aSObject, "AttributeDrawable")
drwAttribute = genericAttribute._narrow(SALOMEDS.AttributeDrawable)
- drwAttribute.SetDrawable(False)
- pass
-
+ drwAttribute.SetDrawable(False)
+ pass
+
# end of l1_geompy_auxiliary
## @}
@@ -4016,7 +4016,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
# selected by they indices in list of all sub-shapes of type aType.
# Each index is in range [1, Nb_Sub-Shapes_Of_Given_Type]
# @param aShape Shape to get sub-shape of.
- # @param aListOfInd List of sub-shapes indices.
+ # @param ListOfInd List of sub-shapes indices.
# @param aType Type of sub-shapes to be retrieved (see ShapeType())
# @return A compound of sub-shapes of aShape.
#
@@ -4096,7 +4096,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
# selected by they indices in sorted list of all sub-shapes of type aType.
# Each index is in range [1, Nb_Sub-Shapes_Of_Given_Type]
# @param aShape Shape to get sub-shape of.
- # @param aListOfInd List of sub-shapes indices.
+ # @param ListOfInd List of sub-shapes indices.
# @param aType Type of sub-shapes to be retrieved (see ShapeType())
# @return A compound of sub-shapes of aShape.
#
@@ -4147,9 +4147,9 @@ class geompyDC(GEOM._objref_GEOM_Gen):
RaiseIfFailed("ExtractSubShapes", self.ShapesOp)
return ListObj
## Get a set of sub-shapes defined by their unique IDs inside theMainShape
# @param theMainShape Main shape.
# @param theIndices List of unique IDs of sub-shapes inside theMainShape.
# @return List of GEOM.GEOM_Object, corresponding to found sub-shapes.
#
# @ref swig_all_decompose "Example"
@@ -4158,8 +4158,8 @@ class geompyDC(GEOM._objref_GEOM_Gen):
Get a set of sub-shapes defined by their unique IDs inside theMainShape
Parameters:
- theMainShape Main shape.
- theIndices List of unique IDs of sub-shapes inside theMainShape.
+ aShape Main shape.
+ anIDs List of unique IDs of sub-shapes inside theMainShape.
Returns:
List of GEOM.GEOM_Object, corresponding to found sub-shapes.
@@ -4805,7 +4805,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
# @param theShape Initial shape.
# @param theTolerance Maximum distance between edges,
# which can be considered as coincident.
- # @param theFaces List of edges for gluing.
+ # @param theEdges List of edges for gluing.
# @return New GEOM.GEOM_Object, containing a copy of theShape
# without some edges.
#
@@ -4819,7 +4819,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
theShape Initial shape.
theTolerance Maximum distance between edges,
which can be considered as coincident.
- theFaces List of edges for gluing.
+ theEdges List of edges for gluing.
Returns:
New GEOM.GEOM_Object, containing a copy of theShape
@@ -4873,7 +4873,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
#
# @ref tui_common "Example 1"
# \n @ref swig_MakeCommon "Example 2"
- def MakeCommon(self, s1, s2):
+ def MakeCommon(self, theShape1, theShape2):
"""
Perform Common boolean operation on two given shapes.
@@ -4885,7 +4885,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
New GEOM.GEOM_Object, containing the result shape.
"""
# Example: see GEOM_TestOthers.py
- return self.MakeBoolean(s1, s2, 1)
+ return self.MakeBoolean(theShape1, theShape2, 1)
## Perform Cut boolean operation on two given shapes.
# @param theShape1 First argument for boolean operation.
@@ -4894,7 +4894,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
#
# @ref tui_cut "Example 1"
# \n @ref swig_MakeCommon "Example 2"
- def MakeCut(self, s1, s2):
+ def MakeCut(self, theShape1, theShape2):
"""
Perform Cut boolean operation on two given shapes.
@@ -4907,7 +4907,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
"""
# Example: see GEOM_TestOthers.py
- return self.MakeBoolean(s1, s2, 2)
+ return self.MakeBoolean(theShape1, theShape2, 2)
## Perform Fuse boolean operation on two given shapes.
# @param theShape1 First argument for boolean operation.
@@ -4916,7 +4916,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
#
# @ref tui_fuse "Example 1"
# \n @ref swig_MakeCommon "Example 2"
- def MakeFuse(self, s1, s2):
+ def MakeFuse(self, theShape1, theShape2):
"""
Perform Fuse boolean operation on two given shapes.
@@ -4929,7 +4929,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
"""
# Example: see GEOM_TestOthers.py
- return self.MakeBoolean(s1, s2, 3)
+ return self.MakeBoolean(theShape1, theShape2, 3)
## Perform Section boolean operation on two given shapes.
# @param theShape1 First argument for boolean operation.
@@ -4938,7 +4938,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
#
# @ref tui_section "Example 1"
# \n @ref swig_MakeCommon "Example 2"
- def MakeSection(self, s1, s2):
+ def MakeSection(self, theShape1, theShape2):
"""
Perform Section boolean operation on two given shapes.
@@ -4951,7 +4951,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
"""
# Example: see GEOM_TestOthers.py
- return self.MakeBoolean(s1, s2, 4)
+ return self.MakeBoolean(theShape1, theShape2, 4)
# end of l3_boolean
## @}
@@ -8475,7 +8475,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
# @param theOriginal geometry object for copy
# @return unique object identifier
# @ingroup l1_geompy_auxiliary
- # @ref swig_all_advanced "Example"
+ # @ref swig_MakeCopy "Example"
def MakeCopy(self,theOriginal):
"""
Create a copy of the given object
@@ -4147,9 +4147,9 @@ class geompyDC(GEOM._objref_GEOM_Gen):
RaiseIfFailed("ExtractSubShapes", self.ShapesOp)
return ListObj
- ## Get a set of sub-shapes defined by their unique IDs inside theMainShape
- # @param theMainShape Main shape.
- # @param theIndices List of unique IDs of sub-shapes inside theMainShape.
+ ## Get a set of sub-shapes defined by their unique IDs inside aShape
+ # @param aShape Main shape.
+ # @param anIDs List of unique IDs of sub-shapes inside aShape.
# @return List of GEOM.GEOM_Object, corresponding to found sub-shapes.
#